<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\V1\Chemicals;

use App\Exceptions\ServerRunTimeException;
use App\Rhawn\Services\Chemsite\ChemsiteCompanyService;
use App\Services\Api\ChemicalsMsdsService;
use App\Services\Api\Chemsite\ChemsiteCustomerService;
use App\Services\CustomerService;
use App\Services\FileService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Http\Controllers\V1\Controller;
use App\Support\Traits\Helpers;

class MsdsController extends Controller
{
    use Helpers;

    public function __construct(ChemicalsMsdsService $chemicalsMsdsService)
    {
        $this->setService($chemicalsMsdsService);
    }

    public function getMsds(Request $request)
    {
        try{
            $customerCode = $request->get('customer_code');
            if(!$customerCode){
                return Response::ok('客户编号不存在!');
            }
            $params = $this->formatKeysfromArray($request->all(),'toUnderScore');
            $cas = $params['cas'];
            $msdsType = $params['msds_type'];

            if(!$cas){
                return Response::ok('验证失败,缺少cas参数!');
            }
            if(!$msdsType){
                return Response::ok('验证失败,缺少msds类型参数!');
            }

            if(!in_array($msdsType, ['cn', 'en'])){
                return Response::ok('验证失败,获取类型错误!');
            }

            $platformCompanyInfo = app(CustomerService::class)->getPlatformCustomer(['cus_number' => $customerCode]);
            $pdf = $this->getService()->getMsds($cas, $msdsType, $platformCompanyInfo);

            return Response::success($this->formatKeysfromArray(['download' => env('DOWNLOAD_URL').$pdf]),'操作成功');
        }catch(\Throwable $exception){
            return $this->returnErrorExecptionResponse($exception,'获取msds失败');
        }
    }

    public function downloadFile($path)
    {
        try{
            ob_end_clean();
            return app(FileService::class)->download($path);
        }catch(\Throwable $exception){
            $this->returnErrorExecptionResponse($exception);
        }
    }

    public function viewPdf($path)
    {
        try{
            ob_end_clean();

            $file = app(FileService::class)->loadFile($path);
            header('content-type: application/pdf');
            echo $file;

        }catch(\Throwable $exception){
            $this->returnErrorExecptionResponse($exception);
        }
    }

    public function viewImage($path)
    {
        try{
            ob_end_clean();

            $fileService = app(FileService::class);
            $image = $fileService->loadFile($path);
            $fileInfo = $fileService->getFileListByUniqueId($path);
            if($fileInfo){
                $fileInfo = current($fileInfo);
                header('content-type:'.$fileInfo['mime_type']);
            }else{
                header('content-type:image/svg+xml');
            }
            echo $image;
        }catch(\Throwable $exception){
            $this->returnErrorExecptionResponse($exception);
        }
    }

}
